@@ -1,4 +1,4 @@
 package Wizard::LDAP::Config;
 $Wizard::LDAP::Config::config = {
-  'ldap-prefs-file' => '/etc/Wizard-LDAP/LDAPprefs'
+  'ldap-prefs-file' => '/etc/Wizard-LDAP/prefs'
 };
